# -*- coding: utf-8 -*-

from random import randint

data= [
      { "word":"abacus","definition":"frame with balls for calculating" },
      { "word":"abate","definition":"to lessen to subside" },
      { "word":"abdication","definition":"giving up control authority" },
      { "word":"aberration","definition":"straying away from what is normal" },
      { "word":"abet","definition":"help/encourage smb (in doing wrong)" },
      { "word":"abeyance","definition":"suspended action" },
      { "word":"abhor","definition":"to hate to detest" },
      { "word":"abide","definition":"be faithful to endure" },
      { "word":"abjure","definition":"promise or swear to give up" },
      { "word":"abraded","definition":"rubbed off worn away by friction" },
      { "word":"abrogate","definition":"repeal or annul by authority" },
      { "word":"abscond","definition":"to go away suddenly (to avoid arrest)" },
      { "word":"abstruse","definition":"difficult to comprehend obscure" },
      { "word":"abut","definition":"border on" },
      { "word":"abysmal","definition":"bottomless extreme" },
      { "word":"acarpous","definition":"effete no longer fertile worn out" },
      { "word":"acclaimed","definition":"welcomed with shouts and approval" },
      { "word":"accolade","definition":"praise approval" },
      { "word":"accretion","definition":"the growing of separate things into one" },
      { "word":"adamant","definition":"kind of stone inflexible" },
      { "word":"admonitory","definition":"containing warning" },
      { "word":"adorn","definition":"add beauty decorate" },
      { "word":"adulteration","definition":"making unpure poorer in quality" },
      { "word":"affable","definition":"polite and friendly" },
      { "word":"affinity","definition":"close connection relationship" },
      { "word":"aggravate","definition":"make worse irritate" },
      { "word":"agile","definition":"active quick-moving" },
      { "word":"agog","definition":"eager/excited" },
      { "word":"ail","definition":"trouble be ill" },
      { "word":"alacrity","definition":"eager and cheerful readiness" },
      { "word":"alcove","definition":"recess/partially enclosed place" },
      { "word":"allegiance","definition":"duty support loyalty" },
      { "word":"alleviate","definition":"make (pain) easier to bear" },
      { "word":"alloy","definition":"to debase by mixing with something inferior" },
      { "word":"aloof","definition":"reserved indifferent" },
      { "word":"amalgamate","definition":"mix combine unite societies" },
      { "word":"ambidextrous","definition":"able to use the left hand or the right equally well" },
      { "word":"ambiguous","definition":"doubtful uncertain" },
      { "word":"ambivalent","definition":"having both of two contrary meanings" },
      { "word":"ameliorate","definition":"improve make better" },
      { "word":"amortize","definition":"end (a debt) by setting aside money" },
      { "word":"anguish","definition":"severe suffering" },
      { "word":"animosity","definition":"strong dislike" },
      { "word":"antidote","definition":"medicine used against a poison or a disease" },
      { "word":"antithetical","definition":"direct opposing" },
      { "word":"apartheid","definition":"brutal racial discrimination" },
      { "word":"aplomb","definition":"self-confidence" },
      { "word":"apostate","definition":"one who abandons long-held religious or political convictions" },
      { "word":"apotheosis","definition":"deification glorification to godliness" },
      { "word":"appease","definition":"make quiet or calm" },
      { "word":"apprehensive","definition":"grasping understanding fear unhappy feeling about future" },
      { "word":"apprise","definition":"give notice to inform" },
      { "word":"approbation","definition":"approval" },
      { "word":"apropos","definition":"appropriate to the situation apt" },
      { "word":"apt","definition":"well-suited quick-witted" },
      { "word":"arabesque","definition":"a complex ornate design" },
      { "word":"arboreal","definition":"of connected with trees" },
      { "word":"ardor","definition":"enthusiasm" },
      { "word":"arduous","definition":"steep difficult ascent laborious" },
      { "word":"argot","definition":"jargon slang" },
      { "word":"arrant","definition":"in the highest degree" },
      { "word":"arrogance","definition":"proud superior manner of behaviour" },
      { "word":"articulate","definition":"speak distinctly connect by joints" },
      { "word":"ascend","definition":"go or come up" },
      { "word":"ascertain","definition":"get to know" },
      { "word":"ascetic","definition":"practicing self-denial austere stark" },
      { "word":"ascribe","definition":"consider to be the origin of or belonging to" },
      { "word":"aseptic","definition":"surgically clean" },
      { "word":"asperity","definition":"roughness harshness ill temper irritability" },
      { "word":"aspersion","definition":"slander" },
      { "word":"assail","definition":"with attack violently" },
      { "word":"assiduous","definition":"diligent hard-working sedulous" },
      { "word":"assuage","definition":"make smth (pain desire) less" },
      { "word":"asterisk","definition":"the mark * (e.g.. omitted letters)" },
      { "word":"astringent","definition":"substance that shrinks" },
      { "word":"astute","definition":"clever quick at seeing to get an advantage" },
      { "word":"atonement","definition":"repayment death of Jesus" },
      { "word":"attenuate","definition":"make thin. weaken enervate" },
      { "word":"attune","definition":"bring into harmony" },
      { "word":"audacious","definition":"daring foolishly bold impudent" },
      { "word":"augury","definition":"omen sign" },
      { "word":"august","definition":"majestic venerable" },
      { "word":"auspicious","definition":"favorable successful prosperous" },
      { "word":"austere","definition":"severely moral and strict simple and plain" },
      { "word":"auxiliary","definition":"helping supporting" },
      { "word":"aver","definition":"affirm assert prove justify" },
      { "word":"aversion","definition":"strong dislike" },
      { "word":"avid","definition":"eager greedy" },
      { "word":"avow","definition":"admit. Declare openly" },
      { "word":"baleful","definition":"harmful ominous causing evil" },
      { "word":"balk","definition":"obstacle purposely to get on the way of" },
      { "word":"baneful","definition":"causing harm or ruin pernicious destructive" },
      { "word":"barrage","definition":"artificial obstacle built across a river" },
      { "word":"barren","definition":"not good enough unable to have young ones without value" },
      { "word":"bask","definition":"in enjoy warmth and light" },
      { "word":"beatify","definition":"to bless make happy or ascribe a virtue to" },
      { "word":"bedizen","definition":"to adorn especially in a cheap showy manner" },
      { "word":"belabor","definition":"beat hard" },
      { "word":"bellicose","definition":"belligerent pugnacious warlike" },
      { "word":"belligerent","definition":"(person nation) waging war" },
      { "word":"benefactor","definition":"person who has given help" },
      { "word":"benevolence","definition":"wish or activity in doing good" },
      { "word":"benign","definition":"kind and gentle mild (climate)" },
      { "word":"bequest","definition":"arrangement to give smth at death" },
      { "word":"berate","definition":"scold sharply" },
      { "word":"bereft","definition":"rob or dispossess of smth (material)" },
      { "word":"bewilder","definition":"puzzle confuse" },
      { "word":"bigot","definition":"stubborn narrow-minded person" },
      { "word":"bilge","definition":"bulge the protuberance of a cask" },
      { "word":"blandishment","definition":"flattery coaxing" },
      { "word":"blandness","definition":"polite manner comforting uninteresting" },
      { "word":"blatant","definition":"noisy and rough" },
      { "word":"blithe","definition":"cheerful casual carefree" },
      { "word":"bogus","definition":"sham counterfeit not genuine" },
      { "word":"boisterous","definition":"loud noisy rough lacking restraint" },
      { "word":"bolster","definition":"give greatly needed support" },
      { "word":"boorish","definition":"crude offensive rude" },
      { "word":"brash","definition":"hasty rush cheeky saucy" },
      { "word":"brass","definition":"yellow metal (mixing copper and zinc)" },
      { "word":"brazen","definition":"made of brass" },
      { "word":"breach","definition":"opening broken place breaking" },
      { "word":"brittle","definition":"easily broken" },
      { "word":"broach","definition":"bring up announce begin to talk about" },
      { "word":"brook","definition":"to tolerate endure" },
      { "word":"buoyant","definition":"able to float light-hearted" },
      { "word":"burgeon","definition":"grow forth send out buds" },
      { "word":"burnish","definition":"to polish rub to a shine" },
      { "word":"cabal","definition":"a scheme or plot a group of plotters" },
      { "word":"cadge","definition":"to beg to get by begging" },
      { "word":"cajole","definition":"use flattery or deceit to persuade" },
      { "word":"calipers","definition":"metal supports attached to the legs measuring instrument" },
      { "word":"calumny","definition":"slander aspersion" },
      { "word":"candid","definition":"frank straight-forward" },
      { "word":"cant","definition":"insincere talk/jargon" },
      { "word":"cantankerous","definition":"bad-tempered/quarrelsome" },
      { "word":"canvass","definition":"discuss thoroughly sort of touting" },
      { "word":"castigate","definition":"to chastise correct by punishing" },
      { "word":"castigation","definition":"severe punishment" },
      { "word":"catalyst","definition":"substance that causes speeding up" },
      { "word":"caustic","definition":"biting sarcastic" },
      { "word":"censure","definition":"expression of blame or disapproval a rebuke" },
      { "word":"centurion","definition":"leader of a unit of 100 soldiers" },
      { "word":"chary","definition":"cautious wary" },
      { "word":"chastened","definition":"corrected punished" },
      { "word":"chastisement","definition":"punishment" },
      { "word":"chauvinist","definition":"a blindly devoted patriot" },
      { "word":"chicanery","definition":"legal trickery/false argument" },
      { "word":"chisel","definition":"steel tool for shaping materials" },
      { "word":"churl","definition":"bad-tempered person" },
      { "word":"clamor","definition":"shout complain with a lot of noise" },
      { "word":"clientele","definition":"customers" },
      { "word":"clinch","definition":"come to grips/settle conclusively" },
      { "word":"cling","definition":"to resist separation" },
      { "word":"clot","definition":"half-solid lump formed from liquid" },
      { "word":"cloture","definition":"closing device (in Parliament) to end a debate by voting" },
      { "word":"coagulation","definition":"change to a thick and solid state" },
      { "word":"coalescing","definition":"coming together and uniting into one substance" },
      { "word":"coax","definition":"get smb to do smth by kindness" },
      { "word":"coda","definition":"passage that completes a piece of music" },
      { "word":"coddle","definition":"treat with care and tenderness" },
      { "word":"coerce","definition":"compel to force to make obedient" },
      { "word":"coeval","definition":"of the same period coexisting" },
      { "word":"cogent","definition":"strong convincing" },
      { "word":"cogitate","definition":"think deeply mediate" },
      { "word":"cognizant","definition":"being fully aware of" },
      { "word":"colander","definition":"bowl-shaped vessel with many holes used to drain off water" },
      { "word":"collusion","definition":"secret agreement for a deceitful purpose" },
      { "word":"combustion","definition":"process of burning" },
      { "word":"commemorate","definition":"keep the memory of" },
      { "word":"commodious","definition":"having plenty of space for what is needed" },
      { "word":"commuter","definition":"person who travels regularly" },
      { "word":"complaisance","definition":"tending to comply obliging willingness to please" },
      { "word":"compunction","definition":"feeling of regret for one's action" },
      { "word":"conceal","definition":"hide keep secret" },
      { "word":"conceit","definition":"over-high opinion of too much pride" },
      { "word":"conciliatory","definition":"reconciling soothing comforting mollifying" },
      { "word":"concord","definition":"agreement or harmony" },
      { "word":"concur","definition":"agree in opinion happen together" },
      { "word":"condense","definition":"increase in density strength make laconic" },
      { "word":"condone","definition":"forgive" },
      { "word":"congeal","definition":"make or become stiff and solid" },
      { "word":"conjoin","definition":"to join together" },
      { "word":"connoisseur","definition":"a person with good judgement (e.g.. in art)" },
      { "word":"connotation","definition":"suggestion in addition to" },
      { "word":"consequential","definition":"pompous self important" },
      { "word":"console","definition":"give comfort or sympathy to" },
      { "word":"conspicuous","definition":"easily seen remarkable" },
      { "word":"consternation","definition":"surprise and fear dismay" },
      { "word":"constrain","definition":"compel" },
      { "word":"constrict","definition":"make tight or smaller" },
      { "word":"consume","definition":"get to the end of" },
      { "word":"consummate","definition":"perfect/make perfect/complete" },
      { "word":"contemn","definition":"to scorn or despise" },
      { "word":"contentious","definition":"argumentative pugnacious combative quarrelsome" },
      { "word":"contiguous","definition":"touching neighboring near" },
      { "word":"contrite","definition":"filled with deep sorrow for wrongdoing" },
      { "word":"contumacious","definition":"insubordinate rebellious" },
      { "word":"conundrum","definition":"a riddle dilemma enigma" },
      { "word":"conviction","definition":"convincing firm belief" },
      { "word":"convoke","definition":"call together summon" },
      { "word":"convoluted","definition":"complicated coiled twisted" },
      { "word":"cordial","definition":"warm and sincere" },
      { "word":"cordon","definition":"line (of police acting as a guard)" },
      { "word":"cornucopia","definition":"abundant supply" },
      { "word":"corporeal","definition":"physical of or for the body" },
      { "word":"correlate","definition":"have a mutual relation" },
      { "word":"corroboration","definition":"additional strengthening evidence" },
      { "word":"countenance","definition":"to favor or approve of" },
      { "word":"counterfeit","definition":"forgery" },
      { "word":"countervail","definition":"counterbalance" },
      { "word":"covert","definition":"disguised" },
      { "word":"covetous","definition":"eagerly desirous" },
      { "word":"cower","definition":"crouch shrink back" },
      { "word":"coy","definition":"shy/modest (esp of a girl)" },
      { "word":"crass","definition":"very great (es. stupidity)" },
      { "word":"cravat","definition":"piece of linen worn as a necktie" },
      { "word":"craven","definition":"cowardly" },
      { "word":"crease","definition":"line made by crushing white line on the ground in cricket" },
      { "word":"credulity","definition":"too great a readiness to believe things" },
      { "word":"credulous","definition":"ready to believe things" },
      { "word":"crush","definition":"press lose shape subdue overwhelm" },
      { "word":"cryptic","definition":"secret with a hidden meaning" },
      { "word":"cumbersome","definition":"burdensome heavy and awkward to carry" },
      { "word":"curmudgeon","definition":"bad-tempered person" },
      { "word":"curriculum","definition":"course of study" },
      { "word":"cursory","definition":"quick hurried" },
      { "word":"curtail","definition":"make shorter then was planned" },
      { "word":"dainty","definition":"pretty/delicate(food)/difficult to please" },
      { "word":"daunt","definition":"intimidate make fearful" },
      { "word":"dawdler","definition":"person who is slow waste of time" },
      { "word":"dearth","definition":"shortage" },
      { "word":"debacle","definition":"a breakup overthrow sudden disaster" },
      { "word":"decorum","definition":"propriety properness" },
      { "word":"decree","definition":"order given by authority" },
      { "word":"decry","definition":"disapprove of" },
      { "word":"defer","definition":"postpone give way (to show respect)" },
      { "word":"deferential","definition":"showing respect" },
      { "word":"defiance","definition":"open disobedience or resistance" },
      { "word":"delineate","definition":"to portray depict sketch out" },
      { "word":"deluge","definition":"great flood heavy rush of water" },
      { "word":"demagogue","definition":"person appealing not to reasons" },
      { "word":"demur","definition":"to hesitate raise objections" },
      { "word":"denigrate","definition":"blacken belittle sully defame" },
      { "word":"denouement","definition":"an outcome or solution the unraveling of a plot" },
      { "word":"deplete","definition":"use until none remains" },
      { "word":"deposition","definition":"dethronement depositing" },
      { "word":"deprave","definition":"make morally bad corrupt" },
      { "word":"deprecate","definition":"protest against express disapproval of" },
      { "word":"dereliction","definition":"deserting and leaving to fall into ruins" },
      { "word":"derision","definition":"ridicule mockery deriding" },
      { "word":"derivative","definition":"unoriginal obtained from another source" },
      { "word":"derogatory","definition":"insulting tending to damage" },
      { "word":"descry","definition":"catch sight of see smth in the distance" },
      { "word":"desiccant","definition":"substance used to absorb moisture" },
      { "word":"desuetude","definition":"cessation of use disuse" },
      { "word":"desultory","definition":"aimless haphazard digressing at random" },
      { "word":"deter","definition":"discourage hinder" },
      { "word":"detraction","definition":"slandering verbal attack aspersion" },
      { "word":"detumescence","definition":"diminishing or lessening of swelling" },
      { "word":"deviance","definition":"being different in moral standards (from normal)" },
      { "word":"dexterity","definition":"skill (esp. in handling)" },
      { "word":"diaphanous","definition":"transparent gauzy" },
      { "word":"diatribe","definition":"bitter and violent attack in words" },
      { "word":"diffidence","definition":"shyness" },
      { "word":"dilate","definition":"speak comprehensively become wider large" },
      { "word":"disallow","definition":"refuse to allow or accept as a correct" },
      { "word":"discern","definition":"see with an effort but clearly" },
      { "word":"discomfit","definition":"confuse embarrass" },
      { "word":"disconcert","definition":"upset the self-possession of" },
      { "word":"discountenance","definition":"refuse to approve of" },
      { "word":"discourse","definition":"speech lecture" },
      { "word":"discredit","definition":"refuse to believe" },
      { "word":"discreet","definition":"careful/prudent" },
      { "word":"discrete","definition":"individually distinct" },
      { "word":"disdain","definition":"look on with contempt" },
      { "word":"disencumber","definition":"free from encumbrance" },
      { "word":"disheveled","definition":"untidy" },
      { "word":"disingenuous","definition":"sophisticated artful trying to deceive cunning" },
      { "word":"disinter","definition":"dig up from the earth" },
      { "word":"dislodge","definition":"move force from the place occupied" },
      { "word":"dismal","definition":"sad gloomy miserable" },
      { "word":"disparate","definition":"essentially different" },
      { "word":"disproof","definition":"proof to the contrary" },
      { "word":"dissemble","definition":"speak or behave so as to hide smth (in mind)" },
      { "word":"disseminate","definition":"distribute (esp. ideas)" },
      { "word":"dissent","definition":"have a different opinion refuse to assent" },
      { "word":"dissolution","definition":"disintegration looseness in morals" },
      { "word":"distraught","definition":"distracted violently upset in mind" },
      { "word":"divergence","definition":"getting farther apart from a point" },
      { "word":"divestiture","definition":"taking off getting rid of giving up" },
      { "word":"divulge","definition":"make known smth secret" },
      { "word":"doggerel","definition":"trivial poorly constructed verse" },
      { "word":"dogmatic","definition":"positive certain arbitrary without room for discussion" },
      { "word":"dolt","definition":"stupid fellow" },
      { "word":"dormant","definition":"in a state of inactivity but awaiting development" },
      { "word":"dote","definition":"show much fondness center one's attention" },
      { "word":"drawl","definition":"slow way of speaking" },
      { "word":"droll","definition":"jesting" },
      { "word":"drone","definition":"male bee person who isn't self-employed" },
      { "word":"drowsiness","definition":"feeling sleepy half asleep" },
      { "word":"dubious","definition":"feeling doubt" },
      { "word":"dud","definition":"no use person smth that fails" },
      { "word":"dulcet","definition":"melodious harmonious" },
      { "word":"dupe","definition":"cheat make a fool of" },
      { "word":"duplicity","definition":"deliberate deception" },
      { "word":"duress","definition":"threats to compel smb" },
      { "word":"dwarf","definition":"person or smb much below the usual size" },
      { "word":"dynamo","definition":"a generator something that produces electric current" },
      { "word":"earthenware","definition":"dishes made of baked clay" },
      { "word":"ebullience","definition":"exuberance outburst of feeling" },
      { "word":"ebullient","definition":"overflowing with enthusiasm showing excitement" },
      { "word":"ecumenical","definition":"representing the whole Christian world" },
      { "word":"edacious","definition":"voracious devouring" },
      { "word":"eddy","definition":"circular or spiral movement (e.g.. of wind)" },
      { "word":"edible","definition":"fit to be eaten/not poisonous" },
      { "word":"effete","definition":"infertile worn out weak" },
      { "word":"efficacy","definition":"production of a desired result" },
      { "word":"effluvia","definition":"outflow in a stream of particles a noxious odor or vapor" },
      { "word":"effrontery","definition":"boldness impudence arrogance" },
      { "word":"egress","definition":"way out exit" },
      { "word":"elaborate","definition":"worked out with much care in great detail" },
      { "word":"elegy","definition":"a lament a melancholy composition" },
      { "word":"elicit","definition":"draw out" },
      { "word":"eloquence","definition":"fluent speaking skillful use of language" },
      { "word":"emaciate","definition":"make thin and weak" },
      { "word":"embellish","definition":"make beautiful" },
      { "word":"embezzle","definition":"use in a wrong way for one's own benefit" },
      { "word":"emote","definition":"stir up excite" },
      { "word":"empirical","definition":"relying on experiment" },
      { "word":"encapsulate","definition":"enclose in capsule" },
      { "word":"encomium","definition":"warm or glowing praise eulogy panegyric" },
      { "word":"encumbrance","definition":"burden things that get on the way of" },
      { "word":"endearing","definition":"making dear or liked" },
      { "word":"endemic","definition":"epidemic" },
      { "word":"endorse","definition":"write one's name on the back of" },
      { "word":"enduring","definition":"lasting" },
      { "word":"enervate","definition":"weaken deprive of strength attenuate" },
      { "word":"engender","definition":"cause produce give rise to" },
      { "word":"engrave","definition":"impress deeply" },
      { "word":"engrossing","definition":"taken up all the time or attention writing in large or formal" },
      { "word":"engulf","definition":"swallow up" },
      { "word":"enigma","definition":"smth that is puzzling" },
      { "word":"enmity","definition":"hatred being an enemy" },
      { "word":"ensign","definition":"flag/badge" },
      { "word":"entangle","definition":"put into difficulties" },
      { "word":"enthral","definition":"please greatly/enslave (fig)" },
      { "word":"entice","definition":"tempt or persuade" },
      { "word":"entreat","definition":"ask earnestly" },
      { "word":"enunciate","definition":"pronounce (words)/express a theory" },
      { "word":"enzyme","definition":"catalyst" },
      { "word":"epicurean","definition":"devoted to pleasure (sensuous enjoyment)" },
      { "word":"epistle","definition":"letter" },
      { "word":"epithet","definition":"adjective" },
      { "word":"epitome","definition":"brief summary representative example a typical model" },
      { "word":"equable","definition":"steady regular" },
      { "word":"equanimity","definition":"calmness of temperament" },
      { "word":"equilibrium","definition":"state of being balanced" },
      { "word":"equipoise","definition":"equal distribution of weight equilibrium" },
      { "word":"equivocal","definition":"having a double or doubtful meaning suspicious" },
      { "word":"equivocate","definition":"try to deceive by equivocal language" },
      { "word":"eradicate","definition":"get rid of pull up by the roots" },
      { "word":"erratic","definition":"irregular in behaviour or opinion" },
      { "word":"erudite","definition":"learned scholarly" },
      { "word":"eschew","definition":"avoid" },
      { "word":"esoteric","definition":"abstruse intended only for a small circle of" },
      { "word":"espouse","definition":"marry give one's support to" },
      { "word":"eulogy","definition":"formal praise panegyric" },
      { "word":"euphoria","definition":"elation state of pleasant excitement" },
      { "word":"euthanasia","definition":"easy and painless death" },
      { "word":"evasive","definition":"tending to evade" },
      { "word":"evince","definition":"to show clearly to indicate" },
      { "word":"evoke","definition":"call up bring out" },
      { "word":"excoriation","definition":"severe criticism" },
      { "word":"exculpate","definition":"to clear from a charge of guilt" },
      { "word":"exhaustive","definition":"complete thorough" },
      { "word":"exigency","definition":"emergency an urgent situation" },
      { "word":"exoneration","definition":"set smb clear free (e.g.. from blame)" },
      { "word":"exorbitant","definition":"much too high or great" },
      { "word":"expatiate","definition":"to roam wander freely" },
      { "word":"expedient","definition":"likely to be useful for a purpose" },
      { "word":"expiation","definition":"ending expiring" },
      { "word":"exploit","definition":"brilliant achievement develop use selfishly" },
      { "word":"expostulate","definition":"argue earnestly to dissuade correct or protest" },
      { "word":"expurgate","definition":"to remove obscenity purify censor" },
      { "word":"exscind","definition":"to cut out cut away" },
      { "word":"extant","definition":"still in existence" },
      { "word":"extempore","definition":"without previous thought or preparation" },
      { "word":"extenuate","definition":"reduce the strength of lessen seriousness partially excuse" },
      { "word":"extinct","definition":"no longer active" },
      { "word":"extinguish","definition":"end the existence of/wipe or put out" },
      { "word":"extirpate","definition":"to destroy exterminate cut out exscind" },
      { "word":"extol","definition":"praise highly" },
      { "word":"extort","definition":"obtain by threats violence" },
      { "word":"extralegal","definition":"outside the law" },
      { "word":"extricable","definition":"that can be freed" },
      { "word":"extrovert","definition":"cheerful person" },
      { "word":"exuberance","definition":"state of growing vigorously being full of life" },
      { "word":"facetious","definition":"humorous funny jocular" },
      { "word":"facile","definition":"easily done" },
      { "word":"fallacious","definition":"based on error" },
      { "word":"falter","definition":"waver/move in an uncertain manner" },
      { "word":"fatuous","definition":"without sense foolish self-satisfaction" },
      { "word":"fawn","definition":"young deer try to win smb's favor" },
      { "word":"feckless","definition":"lacking purpose or vitality ineffective careless" },
      { "word":"fecund","definition":"fertile" },
      { "word":"feint","definition":"pretend" },
      { "word":"felicitous","definition":"apt suitably expressed well chosen apropos" },
      { "word":"felon","definition":"person guilty of murder" },
      { "word":"ferment","definition":"substance become excited" },
      { "word":"ferocity","definition":"savage cruelty" },
      { "word":"ferret","definition":"discover by searching search" },
      { "word":"fervid","definition":"showing earnest feeling" },
      { "word":"fervor","definition":"warmth of feelings earnestness" },
      { "word":"fetid","definition":"stinking" },
      { "word":"fetter","definition":"to shackle put in chains" },
      { "word":"feud","definition":"bitter quarrel over a long period of time" },
      { "word":"fidelity","definition":"loyalty accuracy" },
      { "word":"fidget","definition":"move restlessly make nervous" },
      { "word":"figurehead","definition":"carved image on the prow of a ship" },
      { "word":"finesse","definition":"delicate way of dealing with a situation" },
      { "word":"finical","definition":"too fussy about food clothing etc." },
      { "word":"finicky","definition":"finical" },
      { "word":"fission","definition":"splitting or division (esp. of cells)" },
      { "word":"fixate","definition":"stare at" },
      { "word":"flak","definition":"criticism/anti-aircraft guns" },
      { "word":"flamboyant","definition":"brightly colored florid" },
      { "word":"flaunting","definition":"show off complacently" },
      { "word":"flax","definition":"pale yellow (hair) a plant" },
      { "word":"fledged","definition":"able to fly trained experienced" },
      { "word":"fleet","definition":"number of ships quick-moving" },
      { "word":"flinch","definition":"draw move back wince" },
      { "word":"flop","definition":"fail/move/fall clumsily" },
      { "word":"florid","definition":"very much ornamented naturally red (e.g.. of face)" },
      { "word":"flout","definition":"reject mock to go against (as in going against tradition)" },
      { "word":"fluke","definition":"lucky stroke" },
      { "word":"fluster","definition":"make nervous or confused" },
      { "word":"foible","definition":"defect of character (a person is wrongly proud)" },
      { "word":"foil","definition":"prevent from carrying out contrast" },
      { "word":"foment","definition":"put smth warm (to lessen the pain)" },
      { "word":"foolproof","definition":"incapable of failure or error" },
      { "word":"foppish","definition":"like a man who pays too much attention to his clothes" },
      { "word":"forage","definition":"food for horses and cattle" },
      { "word":"forbear","definition":"refrain from be patient ancestor" },
      { "word":"forbearance","definition":"patience willingness to wait" },
      { "word":"ford","definition":"shallow place in a river (to cross)" },
      { "word":"forestall","definition":"prevent by taking action in advance preempt" },
      { "word":"forfeit","definition":"suffer the loss of smth" },
      { "word":"forge","definition":"workshop for the shaping of metal to shape metal lead" },
      { "word":"forgery","definition":"counterfeit" },
      { "word":"forswear","definition":"renounce disallow repudiate" },
      { "word":"foster","definition":"nurture care for" },
      { "word":"fracas","definition":"noisy quarrel" },
      { "word":"fragile","definition":"easily injured broken or destroyed" },
      { "word":"fragrant","definition":"sweet-smelling" },
      { "word":"frantic","definition":"wildly excited with joy pain anxiety" },
      { "word":"frenetic","definition":"frantic frenzied" },
      { "word":"fret","definition":"worry irritation wear away" },
      { "word":"fringe","definition":"edge ornamental border part of hair over the forehead" },
      { "word":"froward","definition":"intractable not willing to yield or comply stubborn" },
      { "word":"frugal","definition":"careful economical" },
      { "word":"fulmination","definition":"bitter protest" },
      { "word":"fulsome","definition":"disgusting offensive due to excessiveness" },
      { "word":"gainsay","definition":"to deny to oppose" },
      { "word":"garble","definition":"make unfair selection from facts" },
      { "word":"garment","definition":"article of clothing" },
      { "word":"garner","definition":"to gather and save to store up" },
      { "word":"garrulity","definition":"talkativeness" },
      { "word":"garrulous","definition":"too talkative" },
      { "word":"gaucherie","definition":"socially awkward tactless behavior" },
      { "word":"germane","definition":"relevant pertinent to" },
      { "word":"gist","definition":"the point general sense" },
      { "word":"glean","definition":"gather facts in small quantities" },
      { "word":"glib","definition":"ready and smooth but not sincere" },
      { "word":"glimmer","definition":"weak/unsteady light" },
      { "word":"gloat","definition":"over look at with selfish delight" },
      { "word":"glut","definition":"supply to much fill to excess" },
      { "word":"gnaw","definition":"waste away bite steadily" },
      { "word":"goad","definition":"smth urging a person to action" },
      { "word":"gorge","definition":"eat greedily/narrow opening with a stream" },
      { "word":"gossamer","definition":"soft light delicate material" },
      { "word":"gouge","definition":"tool for cutting grooves in wood" },
      { "word":"grandiloquent","definition":"using pompous words" },
      { "word":"grave","definition":"serious requiring consideration" },
      { "word":"graze","definition":"touch or scrape lightly in passing" },
      { "word":"gregarious","definition":"living in societies liking the company" },
      { "word":"grievous","definition":"causing grief or pain serious dire grave" },
      { "word":"grovel","definition":"crawl humble oneself" },
      { "word":"guile","definition":"deceit cunning" },
      { "word":"gullible","definition":"easily gulled" },
      { "word":"gush","definition":"burst out suddenly/talk ardently" },
      { "word":"gust","definition":"outburst of feeling sudden rain wind fire etc." },
      { "word":"hack","definition":"cut roughly hired horse" },
      { "word":"halcyon","definition":"calm and peaceful" },
      { "word":"hallow","definition":"to make holy consecrate" },
      { "word":"harangue","definition":"a long passionate speech" },
      { "word":"harbinger","definition":"smth or smb that foretells the coming of" },
      { "word":"harrow","definition":"to distress create stress or torment" },
      { "word":"haughty","definition":"arrogant conceited" },
      { "word":"heed","definition":"attention/give notice to" },
      { "word":"heinous","definition":"odious (of crime)" },
      { "word":"heresy","definition":"belief contrary to what is generally accepted" },
      { "word":"hermetic","definition":"sealed by fusion" },
      { "word":"heterogeneous","definition":"made up of different kinds" },
      { "word":"hew","definition":"make by hard work cut (by striking)" },
      { "word":"highbrow","definition":"(person) with superior tastes" },
      { "word":"hirsute","definition":"hairy shaggy" },
      { "word":"hoax","definition":"mischievous trick played on smb for a joke" },
      { "word":"hoi","definition":"polloi the masses the rabble" },
      { "word":"hollow","definition":"not soled with hole" },
      { "word":"holster","definition":"leather case for a pistol" },
      { "word":"homiletics","definition":"act of preaching" },
      { "word":"hone","definition":"stone used for sharpening tools" },
      { "word":"hoodwink","definition":"trick mislead" },
      { "word":"hospitable","definition":"liking to give hospitality" },
      { "word":"hubris","definition":"arrogant pride" },
      { "word":"hush","definition":"make or become silent" },
      { "word":"husk","definition":"worthless outside part of anything" },
      { "word":"hypocrisy","definition":"falsely making oneself appear to be good" },
      { "word":"iconoclast","definition":"person who attacks popular beliefs" },
      { "word":"idiosyncrasy","definition":"personal mannerism" },
      { "word":"idolatry","definition":"excessive admiration of" },
      { "word":"idyll","definition":"a carefree episode or experience" },
      { "word":"ignoble","definition":"dishonorable common undignified" },
      { "word":"ignominious","definition":"shameful dishonorable undignified disgraceful" },
      { "word":"illicit","definition":"unlawful forbidden" },
      { "word":"imbroglio","definition":"complicated and embarrassing situation" },
      { "word":"immaculate","definition":"pure faultless" },
      { "word":"imminent","definition":"likely to come or happen soon" },
      { "word":"immutable","definition":"that cannot be changed" },
      { "word":"impair","definition":"worsen diminish in value" },
      { "word":"impassive","definition":"unmoved feeling no sign of passion" },
      { "word":"impecunious","definition":"having little or no money" },
      { "word":"impede","definition":"hinder get in the way of" },
      { "word":"impediment","definition":"smth that hinders (e.g. stammer)" },
      { "word":"impending","definition":"imminent being about to happen expected" },
      { "word":"imperative","definition":"urgent essential" },
      { "word":"imperious","definition":"commanding haughty arrogant" },
      { "word":"impermeable","definition":"that cannot be permeated" },
      { "word":"imperturbable","definition":"calm not capable of being excited" },
      { "word":"impervious","definition":"not allowing to pass through (of materials)" },
      { "word":"imperviousness","definition":"haughty arrogant commanding" },
      { "word":"impetuous","definition":"having sudden energy impulsive thrusting ahead forceful" },
      { "word":"impiety","definition":"lack of reverence or dutifulness" },
      { "word":"implacable","definition":"incapable of being placated unpleasable" },
      { "word":"implicate","definition":"show that smb has a share" },
      { "word":"implicit","definition":"implied though not plainly expressed" },
      { "word":"implosion","definition":"collapse bursting inward" },
      { "word":"importune","definition":"beg urgently solicit (of a prostitute)" },
      { "word":"imprecation","definition":"an invocation of evil a curse" },
      { "word":"impromptu","definition":"without preparation" },
      { "word":"impudent","definition":"rash indiscreet" },
      { "word":"impugned","definition":"challenged to be doubted" },
      { "word":"impute","definition":"to attribute to a cause or source ascribe" },
      { "word":"inadvertent","definition":"not paying proper attention" },
      { "word":"inane","definition":"silly senseless" },
      { "word":"inasmuch","definition":"since because" },
      { "word":"incense","definition":"make angry" },
      { "word":"incessant","definition":"often repeated continual" },
      { "word":"inchoate","definition":"not yet fully formed rudimentary elementary" },
      { "word":"incipient","definition":"beginning" },
      { "word":"incise","definition":"engrave make a cut in" },
      { "word":"incite","definition":"stir up rouse" },
      { "word":"inclined","definition":"directing the mind in a certain direction" },
      { "word":"incongruous","definition":"out of place not in harmony or agreement" },
      { "word":"incorrigibility","definition":"cannot be cured or corrected" },
      { "word":"incredulous","definition":"skeptical unwilling to believe" },
      { "word":"inculcate","definition":"fix firmly by repetition" },
      { "word":"incumbents","definition":"official duties" },
      { "word":"incursion","definition":"a raid a sudden attack" },
      { "word":"indefatigability","definition":"not easily exhaustible tirelessness" },
      { "word":"indelible","definition":"that cannot be rubbed out" },
      { "word":"indigence","definition":"poverty" },
      { "word":"indigenous","definition":"native" },
      { "word":"indistinct","definition":"not easily heard seen clearly marked" },
      { "word":"indolence","definition":"laziness" },
      { "word":"indomitable","definition":"not easily discouraged or subdued" },
      { "word":"indulge","definition":"gratify give way to satisfy allow oneself" },
      { "word":"indulgent","definition":"inclined to indulge" },
      { "word":"ineffable","definition":"to great to be described in words" },
      { "word":"ineluctable","definition":"certain inevitable" },
      { "word":"inept","definition":"unskillful said or done at the wrong time" },
      { "word":"ineptitude","definition":"quality of being unskillful" },
      { "word":"inferno","definition":"hell" },
      { "word":"infuriate","definition":"fill with fury or rage" },
      { "word":"infuse","definition":"put pour fill" },
      { "word":"ingenuous","definition":"naive young artless frank honest sincere" },
      { "word":"ingest","definition":"take in by swallowing" },
      { "word":"inimical","definition":"harmful or friendly" },
      { "word":"inimitable","definition":"defying imitation unmatchable" },
      { "word":"innocuous","definition":"causing no harm" },
      { "word":"inscrutable","definition":"incapable of being discovered or understood" },
      { "word":"insensible","definition":"unconscious unresponsive unaffected" },
      { "word":"insinuate","definition":"suggest unpleasantly make a way for smth gently" },
      { "word":"insipid","definition":"without taste or flavor" },
      { "word":"insouciant","definition":"unconcerned carefree" },
      { "word":"insularity","definition":"narrow-mindedness isolated" },
      { "word":"insurrection","definition":"rising of people to open resistance to" },
      { "word":"interdict","definition":"prohibit forbid" },
      { "word":"interim","definition":"as an installment" },
      { "word":"intersperse","definition":"place here and there" },
      { "word":"intransigence","definition":"unwillingness to compromise stubbornness intractability" },
      { "word":"intransigent","definition":"uncompromising" },
      { "word":"intrepid","definition":"fearless brave undaunted" },
      { "word":"introspection","definition":"examining one's own thoughts and feelings" },
      { "word":"inundate","definition":"flood cover by overflowing" },
      { "word":"inured","definition":"accustomed to adapted" },
      { "word":"invective","definition":"abusive language curses" },
      { "word":"inveigh","definition":"to attack verbally denounce deprecate" },
      { "word":"inveterate","definition":"deep-rooted. long-established" },
      { "word":"invincible","definition":"too strong to be defeated" },
      { "word":"involute","definition":"complex" },
      { "word":"irascible","definition":"irritable easily angered" },
      { "word":"irate","definition":"angry" },
      { "word":"ire","definition":"anger" },
      { "word":"irksome","definition":"tiresome" },
      { "word":"irresolute","definition":"hesitating undecided" },
      { "word":"irrevocable","definition":"final and unalterable" },
      { "word":"itinerate","definition":"to travel from place to place to peregrinate" },
      { "word":"jabber","definition":"talk excitedly utter rapidly" },
      { "word":"jibe","definition":"gibe make fun of" },
      { "word":"jocular","definition":"meant as a joke" },
      { "word":"judicious","definition":"sound in judgment wise" },
      { "word":"knit","definition":"draw together unite firmly" },
      { "word":"labyrinthine","definition":"to entangle the state of affairs" },
      { "word":"lachrymose","definition":"causing tears tearful" },
      { "word":"lackluster","definition":"(of eyes) dull" },
      { "word":"lament","definition":"show feel great sorrow" },
      { "word":"lassitude","definition":"weariness tiredness" },
      { "word":"latent","definition":"present but not yet active developed or visible" },
      { "word":"laudatory","definition":"expressing or giving praise" },
      { "word":"lavish","definition":"giving or producing freely liberally or generously" },
      { "word":"legacy","definition":"smth handed down from ancestors" },
      { "word":"levee","definition":"formal reception/embankment" },
      { "word":"levity","definition":"lack of seriousness" },
      { "word":"libel","definition":"statement that damages reputation" },
      { "word":"liberality","definition":"free giving generosity" },
      { "word":"libertine","definition":"immoral person" },
      { "word":"lien","definition":"legal claim until a debt on it is repaid" },
      { "word":"limn","definition":"paint portray" },
      { "word":"limp","definition":"lacking strength walking unevenly" },
      { "word":"lionize","definition":"treat as a famous person" },
      { "word":"lithe","definition":"bending twisting" },
      { "word":"loll","definition":"rest to sit or stand in a lazy way hang (dog's tongue)" },
      { "word":"lope","definition":"move along with long strides" },
      { "word":"loquacious","definition":"talkative garrulous" },
      { "word":"lucubrate","definition":"write in scholarly fashion" },
      { "word":"luculent","definition":"easily understood lucid clear" },
      { "word":"lugubrious","definition":"mournful excessively sad" },
      { "word":"lull","definition":"become quiet or less active" },
      { "word":"lumber","definition":"move in a clumsy/noisy way" },
      { "word":"luminary","definition":"star light-giving body" },
      { "word":"lurk","definition":"be out of view ready to attack" },
      { "word":"lustrous","definition":"being bright polished" },
      { "word":"macabre","definition":"gruesome suggesting death" },
      { "word":"macerate","definition":"make or become soft by soaking in water" },
      { "word":"machination","definition":"plot scheme (esp. evil)" },
      { "word":"maladroit","definition":"tactless clumsy" },
      { "word":"malapropism","definition":"misuse of a word (for one that resembles it)" },
      { "word":"malevolence","definition":"wishing to do evil" },
      { "word":"malign","definition":"injurious speak ill of smb tell lie" },
      { "word":"malinger","definition":"to fake illness or injury in order to shirk a duty" },
      { "word":"malleable","definition":"yielding easily shaped moldable adapting" },
      { "word":"manacle","definition":"chains for the hands or feet" },
      { "word":"massacre","definition":"cruel killing of a large number of people" },
      { "word":"matriculation","definition":"be admitted enter a university as a student" },
      { "word":"maudlin","definition":"sentimental in a silly or tearful way" },
      { "word":"maul","definition":"hurt by rough handling" },
      { "word":"maverick","definition":"rebel nonconformist" },
      { "word":"mellifluous","definition":"sweetly flowing" },
      { "word":"mendacity","definition":"dishonesty" },
      { "word":"mendicant","definition":"a beggar" },
      { "word":"mercurial","definition":"quick changeable in character fleeting" },
      { "word":"meretricious","definition":"attractive on the surface but of little value" },
      { "word":"mesmerize","definition":"hypnotize" },
      { "word":"meticulous","definition":"giving great attention to details" },
      { "word":"mettle","definition":"quality of endurance or courage" },
      { "word":"mettlesome","definition":"courageous high-spirited" },
      { "word":"middling","definition":"fairly good but not very good" },
      { "word":"minatory","definition":"menacing threatening" },
      { "word":"mince","definition":"pronounce or speak affectedly euphemize" },
      { "word":"misanthrope","definition":"person who hates mankind" },
      { "word":"mischievous","definition":"harmful causing mischief" },
      { "word":"miser","definition":"person who loves wealth and spends little" },
      { "word":"misogynist","definition":"one who hates women/females" },
      { "word":"moderation","definition":"quality of being limited not extreme" },
      { "word":"mollify","definition":"make calmer or quieter" },
      { "word":"molt","definition":"moult lose hair feathers before new growing" },
      { "word":"morbid","definition":"diseased unhealthy (e.g.. about ideas)" },
      { "word":"morose","definition":"ill-tempered unsocial" },
      { "word":"muffler","definition":"cloth worn round the neck/silencer" },
      { "word":"multifarious","definition":"varied motley greatly diversified" },
      { "word":"mundane","definition":"worldly as opposed to spiritual commonplace everyday" },
      { "word":"myriad","definition":"very great number" },
      { "word":"nadir","definition":"lowest weakest point" },
      { "word":"nascent","definition":"coming into existence emerging" },
      { "word":"nebulous","definition":"cloud-like hazy vague indistinct" },
      { "word":"negligent","definition":"taking too little care" },
      { "word":"neophyte","definition":"person who has been converted to a belief" },
      { "word":"nexus","definition":"a connection tie or link" },
      { "word":"nibble","definition":"show some inclination to accept (an offer)" },
      { "word":"noisome","definition":"offensive disgusting (smell)" },
      { "word":"nonchalant","definition":"not having interest" },
      { "word":"nonplused","definition":"greatly surprised" },
      { "word":"nostrum","definition":"a quack remedy an untested cure" },
      { "word":"noxious","definition":"harmful" },
      { "word":"nugatory","definition":"trifling/worthless" },
      { "word":"obdurate","definition":"hardened and unrepenting stubborn inflexible" },
      { "word":"obfuscate","definition":"to darken make obscure muddle" },
      { "word":"oblivious","definition":"unaware having no memory" },
      { "word":"obloquy","definition":"abusively detractive language sharp criticism vituperation" },
      { "word":"obsequious","definition":"too eager to obey or serve" },
      { "word":"obstreperous","definition":"noisy loud" },
      { "word":"obtain","definition":"to be established accepted or customary" },
      { "word":"obtrusive","definition":"projecting prominent undesirably noticeable" },
      { "word":"obtuse","definition":"blunt/stupid" },
      { "word":"obviate","definition":"to make unnecessary get rid of" },
      { "word":"occluded","definition":"blocked up" },
      { "word":"odious","definition":"repulsive hateful" },
      { "word":"odium","definition":"contempt dislike aversion" },
      { "word":"odor","definition":"smell favor reputation" },
      { "word":"officious","definition":"too eager or ready to help offer advice" },
      { "word":"ominous","definition":"threatening" },
      { "word":"onerous","definition":"needing effort burdensome" },
      { "word":"opaqueness","definition":"dullness/not allowing light to pass through" },
      { "word":"opprobrious","definition":"showing scorn or reproach" },
      { "word":"ossify","definition":"to turn to bone to settle rigidly into an idea" },
      { "word":"ostensible","definition":"seeming appearing as such professed" },
      { "word":"ostentation","definition":"display to obtain admiration or envy" },
      { "word":"ostracism","definition":"shut out from society refuse to meet talk" },
      { "word":"overhaul","definition":"examine thoroughly to learn about the condition" },
      { "word":"overweening","definition":"presumptuously arrogant overbearing immoderate being a jerk" },
      { "word":"paean","definition":"song of praise or triumph" },
      { "word":"palate","definition":"roof of the mouth sense of taste" },
      { "word":"palatial","definition":"magnificent" },
      { "word":"palliate","definition":"lessen the severity of" },
      { "word":"palpability","definition":"can be felt touched understood" },
      { "word":"palpitate","definition":"tremble beat rapidly and irregularly" },
      { "word":"panegyric","definition":"formal praise eulogy" },
      { "word":"paradigm","definition":"a model example or pattern" },
      { "word":"parenthesis","definition":"sentence within another one smth separated" },
      { "word":"pariah","definition":"an outcast a rejected and despised person" },
      { "word":"parsimonious","definition":"too economical miserly" },
      { "word":"partisan","definition":"one-sided committed to a party biased or prejudiced" },
      { "word":"patron","definition":"regular customer person who gives support" },
      { "word":"paucity","definition":"scarcity a lacking of" },
      { "word":"peccadillo","definition":"small sin small weakness in one's character" },
      { "word":"pedantic","definition":"bookish showing off learning" },
      { "word":"pedestrian","definition":"commonplace trite unremarkable" },
      { "word":"pellucid","definition":"transparent easy to understand" },
      { "word":"penchant","definition":"strong inclination a liking" },
      { "word":"penitent","definition":"feeling or showing regret" },
      { "word":"penurious","definition":"poor/stingy" },
      { "word":"penury","definition":"extreme poverty" },
      { "word":"peregrination","definition":"traveling about wandering" },
      { "word":"peremptory","definition":"urgent imperative unchallengeable ending debate" },
      { "word":"perfidious","definition":"treacherous faithless" },
      { "word":"perfidy","definition":"treachery breaking of faith" },
      { "word":"perfunctory","definition":"done as a duty without care" },
      { "word":"perilous","definition":"dangerous" },
      { "word":"peripatetic","definition":"wandering" },
      { "word":"perish","definition":"be destroyed decay" },
      { "word":"perjury","definition":"willful FALSE statement unlawful act" },
      { "word":"permeate","definition":"spread into every part of" },
      { "word":"pernicious","definition":"harmful injurious" },
      { "word":"perpetrate","definition":"be guilty commit (a crime)" },
      { "word":"personable","definition":"pleasing in appearance attractive" },
      { "word":"perspicacity","definition":"quick judging and understanding" },
      { "word":"pertain","definition":"belong as a part have reference" },
      { "word":"pest","definition":"destructive thing or a person who is nuisance" },
      { "word":"petrified","definition":"taken away power (to think feel act)" },
      { "word":"petrify","definition":"to make hard rocklike" },
      { "word":"petrous","definition":"like a rock hard stony" },
      { "word":"petulant","definition":"unreasonably impatient" },
      { "word":"philistine","definition":"a smug ignorant person one who lacks knowledge" },
      { "word":"phlegmatic","definition":"calm sluggish temperament unemotional" },
      { "word":"picaresque","definition":"involving clever rogues or adventurers" },
      { "word":"pied","definition":"of mixed colors" },
      { "word":"pinch","definition":"be too tight take between the thumb and finger" },
      { "word":"pine","definition":"waste away through sorrow or illness" },
      { "word":"pious","definition":"dutiful to parents devoted to religion" },
      { "word":"piquant","definition":"agreeably pungent stimulating" },
      { "word":"pique","definition":"hurt the pride or self-respect stir (curiosity)" },
      { "word":"pitfall","definition":"covered hole as a trap unsuspected danger" },
      { "word":"pith","definition":"essential part force soft liquid substance" },
      { "word":"pivotal","definition":"of great importance (others depend on it)" },
      { "word":"placate","definition":"soothe pacify calm" },
      { "word":"plaintive","definition":"mournful melancholy sorrowful" },
      { "word":"plaque","definition":"flat metal on a wall as a memorial" },
      { "word":"platitude","definition":"a trite or banal statement unoriginality" },
      { "word":"plea","definition":"request" },
      { "word":"plead","definition":"address a court of law as an advocate" },
      { "word":"plethora","definition":"glut" },
      { "word":"pliant","definition":"pliable easily bent shaped or twisted" },
      { "word":"plod","definition":"continue doing smth without resting" },
      { "word":"pluck","definition":"pull the feathers off pick (e.g.. flowers)" },
      { "word":"plumb","definition":"get to the root of" },
      { "word":"plummet","definition":"fall plunge steeply" },
      { "word":"plunge","definition":"move quickly suddenly and with force" },
      { "word":"poignant","definition":"deeply moving keen" },
      { "word":"poncho","definition":"large piece of cloth" },
      { "word":"ponderous","definition":"heavy bulky dull" },
      { "word":"portent","definition":"omen marvelous threatening" },
      { "word":"precarious","definition":"uncertain risky dangerous" },
      { "word":"precepts","definition":"rules establishing standards of conduct" },
      { "word":"preclude","definition":"prevent make impossible" },
      { "word":"precursory","definition":"preliminary anticipating" },
      { "word":"predilection","definition":"special liking mental preference" },
      { "word":"predominate","definition":"have more power than others" },
      { "word":"preen","definition":"tidy/show self-satisfaction" },
      { "word":"premature","definition":"doing or happening smth before the right time" },
      { "word":"preponderance","definition":"greatness in number strength weight" },
      { "word":"presage","definition":"warning sign" },
      { "word":"presumption","definition":"arrogance" },
      { "word":"preternatural","definition":"not normal or usual" },
      { "word":"prevalent","definition":"common" },
      { "word":"prevaricate","definition":"to equivocate to stray from the truth" },
      { "word":"prim","definition":"neat formal" },
      { "word":"pristine","definition":"primitive unspoiled pure as in earlier times unadulterated" },
      { "word":"probity","definition":"uprightness incorruptibility principle" },
      { "word":"proclivity","definition":"inclination" },
      { "word":"procrastination","definition":"keeping on putting off" },
      { "word":"prodigal","definition":"wasteful reckless with money" },
      { "word":"prodigious","definition":"enormous wonderful" },
      { "word":"profane","definition":"worldly having contempt for God" },
      { "word":"profligacy","definition":"shameless immorality" },
      { "word":"profligate","definition":"wasteful prodigal licentious extravagant" },
      { "word":"profundity","definition":"depth" },
      { "word":"profuse","definition":"abundant/lavish" },
      { "word":"proliferate","definition":"grow reproduce by rapid multification" },
      { "word":"prolix","definition":"tiring because too long" },
      { "word":"prone","definition":"prostrate inclined to (undesirable things)" },
      { "word":"propagation","definition":"increasing the number spreading extending" },
      { "word":"propinquity","definition":"nearness in time or place affinity of nature" },
      { "word":"propitiatory","definition":"conciliatory appeasing mitigating" },
      { "word":"propitious","definition":"auspicious presenting favorable circumstances" },
      { "word":"prosaic","definition":"everyday mundane commonplace trite pedestrian" },
      { "word":"proscribe","definition":"denounce as dangerous" },
      { "word":"protracted","definition":"prolonged" },
      { "word":"provident","definition":"frugal looking to the future" },
      { "word":"provisional","definition":"of the present time only" },
      { "word":"provoke","definition":"make angry vax" },
      { "word":"prudence","definition":"careful forethought" },
      { "word":"prudish","definition":"easily shocked excessively modest" },
      { "word":"prune","definition":"dried plum silly person" },
      { "word":"pry","definition":"get smth inquire too curiously" },
      { "word":"pucker","definition":"wrinkle" },
      { "word":"pugnacious","definition":"fond of in the habit of fighting" },
      { "word":"puissance","definition":"strength" },
      { "word":"punctilious","definition":"precise paying attention to trivialities" },
      { "word":"pundit","definition":"pedant authority on a subject" },
      { "word":"pungency","definition":"sharpness stinging quality" },
      { "word":"purvey","definition":"provide supply" },
      { "word":"pusillanimous","definition":"cowardly craven" },
      { "word":"putrefaction","definition":"becoming rotten" },
      { "word":"pyre","definition":"large pile of wood for burning" },
      { "word":"quack","definition":"person dishonestly claiming to smth" },
      { "word":"quaff","definition":"drink deeply" },
      { "word":"quail","definition":"lose courage turn frightened" },
      { "word":"qualm","definition":"feeling of doubt temporary feeling of sickness" },
      { "word":"quandary","definition":"state of doubt or perplexity" },
      { "word":"quell","definition":"suppress subdue" },
      { "word":"quibble","definition":"try to avoid by sophistication" },
      { "word":"quiescence","definition":"state of being passive/motionless" },
      { "word":"quiescent","definition":"at rest dormant torpid" },
      { "word":"quirk","definition":"habit or action peculiar to smb or smth" },
      { "word":"quixotic","definition":"generous unselfish" },
      { "word":"quotidian","definition":"banal everyday" },
      { "word":"rabble","definition":"mob crowd the lower classes of populace" },
      { "word":"raconteur","definition":"person who tells anecdotes" },
      { "word":"raffish","definition":"low vulgar base tawdry" },
      { "word":"ramify","definition":"to be divided or subdivided to branch out" },
      { "word":"rancorous","definition":"feeling bitterness spitefulness" },
      { "word":"rant","definition":"use extravagant language" },
      { "word":"rapacious","definition":"greedy (esp for money)" },
      { "word":"rarefy","definition":"to make thin to make less dense to purify or refine" },
      { "word":"rave","definition":"act with excessive enthusiasm" },
      { "word":"reactionary","definition":"opposing progress" },
      { "word":"rebuff","definition":"snub" },
      { "word":"recalcitrant","definition":"disobedient" },
      { "word":"recant","definition":"take back as being FALSE give up" },
      { "word":"recast","definition":"cast or fashion anew" },
      { "word":"recidivism","definition":"relapse into antisocial or criminal behavior" },
      { "word":"reciprocity","definition":"granting of privileges in return for similar" },
      { "word":"recitals","definition":"a number of performance of music" },
      { "word":"recluse","definition":"person who lives alone and avoids people" },
      { "word":"recompense","definition":"make payment to reward punish" },
      { "word":"reconcile","definition":"settle a quarrel restore peace" },
      { "word":"recondite","definition":"little known abstruse" },
      { "word":"recreancy","definition":"cowardice a cowardly giving up" },
      { "word":"recuperate","definition":"become strong after illness loss exhaustion" },
      { "word":"redeem","definition":"get back by payment compensate" },
      { "word":"redoubtable","definition":"formidable causing fear" },
      { "word":"refine","definition":"make or become pure cultural" },
      { "word":"refractory","definition":"stubborn unmanageable untractable" },
      { "word":"refulgent","definition":"shining brilliant" },
      { "word":"regale","definition":"to delight or entertain to feast" },
      { "word":"regicide","definition":"crime of killing a king" },
      { "word":"reiterate","definition":"say or do again several times" },
      { "word":"rejuvenation","definition":"becoming young in nature or appearance" },
      { "word":"relapse","definition":"fall back again" },
      { "word":"remonstrate","definition":"to protest object" },
      { "word":"render","definition":"deliver provide represent" },
      { "word":"renovate","definition":"restore smth to better condition" },
      { "word":"renowned","definition":"celebrated famous" },
      { "word":"repast","definition":"meal" },
      { "word":"repel","definition":"refuse to accept/cause dislike" },
      { "word":"repine","definition":"at be discontented with" },
      { "word":"reproach","definition":"scold upbraid" },
      { "word":"reprobate","definition":"person hardened in sin one devoid of decency" },
      { "word":"repudiate","definition":"disown refuse to accept or pay" },
      { "word":"repulsive","definition":"causing a feeling of disgust" },
      { "word":"requite","definition":"repay give in return" },
      { "word":"rescind","definition":"repeal/annul/cancel" },
      { "word":"resigned","definition":"unresisting submissive" },
      { "word":"resilience","definition":"quality of quickly recovering the original shape" },
      { "word":"resort","definition":"to frequently visit" },
      { "word":"restive","definition":"refusing to move reluctant to be controlled" },
      { "word":"resuscitation","definition":"coming back to consciousness" },
      { "word":"retard","definition":"check hinder" },
      { "word":"reticent","definition":"reserved untalkative silent taciturn" },
      { "word":"revere","definition":"have deep respect for" },
      { "word":"reverent","definition":"feeling or showing deep respect" },
      { "word":"riddle","definition":"puzzling person or thing" },
      { "word":"rift","definition":"split crack dissension" },
      { "word":"rivet","definition":"fix take up secure metal pin" },
      { "word":"roll","definition":"call calling of names" },
      { "word":"rotund","definition":"rich and deep plump and round" },
      { "word":"ruffian","definition":"violent cruel man" },
      { "word":"rumple","definition":"make rough" },
      { "word":"sagacious","definition":"having sound judgment perceptive wise like a sage" },
      { "word":"salacious","definition":"obscene" },
      { "word":"salubrious","definition":"healthful" },
      { "word":"salutary","definition":"remedial wholesome causing improvement" },
      { "word":"sanctimony","definition":"self-righteousness hypocritical with FALSE piety" },
      { "word":"sanction","definition":"approval (by authority) penalty" },
      { "word":"sanguine","definition":"cheerful confident optimistic" },
      { "word":"sanity","definition":"health of mind soundness of judgement" },
      { "word":"sash","definition":"long strip worn round the waist" },
      { "word":"satiate","definition":"satisfy fully" },
      { "word":"saturnine","definition":"gloomy dark sullen morose" },
      { "word":"savant","definition":"person of great learning" },
      { "word":"savor","definition":"taste flavor smth" },
      { "word":"sawdust","definition":"tiny bits of wood" },
      { "word":"scabbard","definition":"sheath for the blade" },
      { "word":"scent","definition":"smell (esp pleasant)" },
      { "word":"scorch","definition":"become discolored/dry up/go at high speed" },
      { "word":"scribble","definition":"write hastily" },
      { "word":"scurvy","definition":"mean contemptible" },
      { "word":"secular","definition":"material (not spiritual) living outside monasteries" },
      { "word":"sedulous","definition":"persevering" },
      { "word":"seminal","definition":"like a seed constituting a source originative" },
      { "word":"sententious","definition":"short and pithy full of maxims/proverbs" },
      { "word":"sequence","definition":"succession connected line of" },
      { "word":"sere","definition":"make hard and without feeling" },
      { "word":"sermon","definition":"reproving a person for his faults" },
      { "word":"serrated","definition":"having a toothed edge" },
      { "word":"serration","definition":"having a toothed edge" },
      { "word":"servile","definition":"like a slave lacking independence" },
      { "word":"sever","definition":"break off" },
      { "word":"severance","definition":"severing" },
      { "word":"shallow","definition":"little depth not earnest" },
      { "word":"shard","definition":"piece of broken earthenware" },
      { "word":"sheath","definition":"cover for the blade of a weapon or a tool" },
      { "word":"shrewd","definition":"astute showing sound judgement" },
      { "word":"shrill","definition":"sharp piercing" },
      { "word":"shun","definition":"keep away from avoid" },
      { "word":"shunt","definition":"send from one track to another lay aside evade discussion" },
      { "word":"sidestep","definition":"step to one side" },
      { "word":"simper","definition":"(give a) silly/self-conscious smile" },
      { "word":"sinuous","definition":"winding undulating serpentine" },
      { "word":"skiff","definition":"small boat" },
      { "word":"skit","definition":"short piece of humorous writing" },
      { "word":"slack","definition":"sluggish dull not tight" },
      { "word":"slake","definition":"to assuage to satisfy allay" },
      { "word":"slate","definition":"king of blue-grey stone propose criticize" },
      { "word":"sluggard","definition":"lazy slow-moving person" },
      { "word":"slur","definition":"join sounds/words (indistinct)" },
      { "word":"smolder","definition":"burn slowly without flame" },
      { "word":"snare","definition":"trap" },
      { "word":"snub","definition":"treat with contempt" },
      { "word":"soar","definition":"rise fly high" },
      { "word":"sober","definition":"self-controlled" },
      { "word":"sobriety","definition":"quality or condition of being sober" },
      { "word":"sodden","definition":"soaked saturated" },
      { "word":"soggy","definition":"heavy with water" },
      { "word":"solvent","definition":"of the power of forming a solution" },
      { "word":"somatic","definition":"of the body" },
      { "word":"soot","definition":"black powder in smoke" },
      { "word":"sophisticated","definition":"complex subtle refined" },
      { "word":"sophistry","definition":"fallacious reasoning faulty logic" },
      { "word":"sophomoric","definition":"self-assured though immature affected bombastic overblown" },
      { "word":"soporific","definition":"producing sleep" },
      { "word":"sordid","definition":"wretched comfortless contemptible" },
      { "word":"spear","definition":"weapon with a metal point on a long shaft" },
      { "word":"specious","definition":"illogical of questionable truth or merit" },
      { "word":"splenetic","definition":"bad-tempered irritable" },
      { "word":"splice","definition":"join (two ends)" },
      { "word":"sponge","definition":"porous rubber for washing live at once expense" },
      { "word":"spurious","definition":"FALSE counterfeit" },
      { "word":"spurn","definition":"have nothing to do reject or refuse" },
      { "word":"squalid","definition":"foul filthy" },
      { "word":"squander","definition":"spend wastefully" },
      { "word":"squat","definition":"crouch/settle without permission" },
      { "word":"stanch","definition":"to stop the flow of a fluid" },
      { "word":"steeply","definition":"rising or falling sharply" },
      { "word":"stentorian","definition":"extremely loud and powerful" },
      { "word":"stickler","definition":"person who insists on importance of smth" },
      { "word":"stigma","definition":"mark of shame or disgrace" },
      { "word":"stigmatize","definition":"describe smb scornfully" },
      { "word":"sting","definition":"smth sharp" },
      { "word":"stingy","definition":"spending using unwillingly" },
      { "word":"stint","definition":"to be thrifty to set limits" },
      { "word":"stipple","definition":"paint with dots" },
      { "word":"stipulate","definition":"state or put forward as a necessary condition" },
      { "word":"stolid","definition":"showing no emotion impassive" },
      { "word":"stray","definition":"wander lose one's way" },
      { "word":"streak","definition":"long thin move very fast" },
      { "word":"striated","definition":"striped grooved or banded" },
      { "word":"stride","definition":"walk with long steps" },
      { "word":"strut","definition":"a supporting bar" },
      { "word":"stygian","definition":"hence dark gloomy" },
      { "word":"stymie","definition":"to hinder obstruct or block" },
      { "word":"subdue","definition":"overcome bring under control" },
      { "word":"sublime","definition":"extreme astounding" },
      { "word":"submerge","definition":"put under water liquid sink out of sight" },
      { "word":"suborn","definition":"induce by bribery or smth to commit perjury" },
      { "word":"subpoena","definition":"written order requiring a person to appear in a low court" },
      { "word":"substantiation","definition":"giving facts to support (statement)" },
      { "word":"subsume","definition":"include under a rule" },
      { "word":"succor","definition":"assistance relief in time of distress" },
      { "word":"suffice","definition":"be enough" },
      { "word":"suffocate","definition":"cause or have difficulty in breathing" },
      { "word":"sullied","definition":"to be stained or discredited" },
      { "word":"summarily","definition":"briefly without delay" },
      { "word":"sumptuous","definition":"magnificent" },
      { "word":"sundry","definition":"various miscellaneous separate" },
      { "word":"supercilious","definition":"disdainful characterized by haughty scorn" },
      { "word":"superfluous","definition":"more then is needed or wanted" },
      { "word":"superimpose","definition":"put smth on the top" },
      { "word":"supersede","definition":"take the place of" },
      { "word":"supine","definition":"lying on the back slow to act passive" },
      { "word":"suppliant","definition":"asking humbly beseeching" },
      { "word":"supplicate","definition":"make a humble petition to" },
      { "word":"suppress","definition":"prevent from being known put an end to" },
      { "word":"surcharge","definition":"additional load/charge" },
      { "word":"surfeit","definition":"satiate feed to fulness or to excess" },
      { "word":"susceptibility","definition":"sensitiveness" },
      { "word":"swerve","definition":"change direction suddenly" },
      { "word":"sycophant","definition":"person who flatter to the rich and powerful" },
      { "word":"synopsis","definition":"summary or outline" },
      { "word":"taciturn","definition":"untalkative silent" },
      { "word":"tadpole","definition":"form of a frog when it leaves the egg" },
      { "word":"talon","definition":"claw of a bird of prey" },
      { "word":"tamp","definition":"tap or drive down by repeated light blows" },
      { "word":"tamper","definition":"interfere with" },
      { "word":"tangential","definition":"suddenly changeable" },
      { "word":"tarnished","definition":"lost brightness" },
      { "word":"tassel","definition":"bunch of threads" },
      { "word":"taunt","definition":"contemptuous reproach hurtful remark" },
      { "word":"taut","definition":"tightly stretched" },
      { "word":"tautology","definition":"a repetition a redundancy" },
      { "word":"tawdry","definition":"cheap gaudy showy tacky" },
      { "word":"teetotal","definition":"oppose to alcohol" },
      { "word":"temerity","definition":"boldness brashness intrepidness" },
      { "word":"temperance","definition":"abstinence from alcohol self-control moderation" },
      { "word":"temperate","definition":"showing self-control" },
      { "word":"tenacity","definition":"firmness persistency adhesiveness tending to hang on" },
      { "word":"tenuous","definition":"insubstantial flimsy weak" },
      { "word":"tepid","definition":"lukewarm" },
      { "word":"terse","definition":"brief and to the point" },
      { "word":"testiness","definition":"witness/evidence" },
      { "word":"thrift","definition":"care economy thriving prosperous" },
      { "word":"thwart","definition":"obstruct/frustrate" },
      { "word":"timid","definition":"shy easily frightened" },
      { "word":"timorous","definition":"fearful timid afraid" },
      { "word":"toady","definition":"obsequious flatterer" },
      { "word":"tonic","definition":"smth giving strength or energy" },
      { "word":"topple","definition":"be unsteady and overturn" },
      { "word":"torment","definition":"severe pain or suffering" },
      { "word":"torpid","definition":"sleeping sluggish lethargic dormant" },
      { "word":"torque","definition":"twisting force causing rotation" },
      { "word":"tortuous","definition":"devious/not straightforward" },
      { "word":"tout","definition":"person who worries others to buy smth to use his service" },
      { "word":"tractable","definition":"easily controlled or guided" },
      { "word":"transgress","definition":"break go beyond (a limit)" },
      { "word":"transient","definition":"temporary fleeting" },
      { "word":"transitory","definition":"brief" },
      { "word":"travesty","definition":"parody/imitation" },
      { "word":"trenchant","definition":"forceful effective vigorous extremely perceptive incisive" },
      { "word":"trepidation","definition":"alarm excited state of mind" },
      { "word":"trickle","definition":"flow in drops" },
      { "word":"trifling","definition":"unimportant" },
      { "word":"trite","definition":"not new" },
      { "word":"truce","definition":"(agreement) stop of fighting for a time" },
      { "word":"truculence","definition":"aggressiveness ferocity" },
      { "word":"trudge","definition":"walk heavily" },
      { "word":"turbid","definition":"muddy having the sediment stirred up" },
      { "word":"turbulence","definition":"being uncontrolled violent" },
      { "word":"turgid","definition":"excessively ornate swollen or bloated" },
      { "word":"turmoil","definition":"trouble disturbance" },
      { "word":"turpitude","definition":"wickedness shamefulness" },
      { "word":"turquoise","definition":"greenish-blue precious stone" },
      { "word":"tyro","definition":"tiro beginner" },
      { "word":"ubiquitous","definition":"present everywhere" },
      { "word":"ulterior","definition":"situated beyond" },
      { "word":"umbrage","definition":"offense resentment" },
      { "word":"uncouth","definition":"rough awkward" },
      { "word":"underbid","definition":"make a lower bid then smb else" },
      { "word":"undermine","definition":"weaken gradually at the base make smth under" },
      { "word":"undulate","definition":"to move in wavelike fashion fluctuate" },
      { "word":"unearth","definition":"discover and bring to light" },
      { "word":"unencumbered","definition":"easy-going trifle" },
      { "word":"unfeigned","definition":"not pretended sincere" },
      { "word":"unscathed","definition":"unharmed unhurt" },
      { "word":"untoward","definition":"unfortunate inconvenient" },
      { "word":"upbraid","definition":"scold reproach" },
      { "word":"urbane","definition":"elegant refined in manners" },
      { "word":"vacillation","definition":"being uncertain hesitating" },
      { "word":"vagary","definition":"strange act or idea" },
      { "word":"vain","definition":"without use result conceited" },
      { "word":"valiant","definition":"brave" },
      { "word":"valorous","definition":"brave" },
      { "word":"vanquish","definition":"conquer" },
      { "word":"veer","definition":"change direction" },
      { "word":"venal","definition":"ready to do smth dishonest" },
      { "word":"veneer","definition":"surface appearance covering the TRUE nature" },
      { "word":"veneration","definition":"regard with deep respect" },
      { "word":"veracity","definition":"truth" },
      { "word":"verdant","definition":"fresh and green" },
      { "word":"verisimilitude","definition":"appearing TRUE or real" },
      { "word":"veritable","definition":"real rightly named" },
      { "word":"verve","definition":"spirit vigor enthusiasm" },
      { "word":"vestige","definition":"trace or sign" },
      { "word":"vex","definition":"annoy distress trouble" },
      { "word":"vigilance","definition":"watchfulness self-appointed group who maintain order" },
      { "word":"vigilant","definition":"member of a vigilance committee" },
      { "word":"vigorous","definition":"strong energetic" },
      { "word":"vilify","definition":"slander say evil things" },
      { "word":"vindictive","definition":"having a desire to revenge" },
      { "word":"virago","definition":"a loud domineering woman a scold or nag" },
      { "word":"visceral","definition":"of the internal organs of the body" },
      { "word":"viscous","definition":"sticky/semi-fluid" },
      { "word":"vitiate","definition":"lower the quality weaken the strength" },
      { "word":"vituperate","definition":"curse abuse in words" },
      { "word":"vivacious","definition":"lively high-spirited" },
      { "word":"volatile","definition":"changeable inconstant fickle unstable explosive" },
      { "word":"volubility","definition":"fluency verbosity easy use of spoken language" },
      { "word":"voluble","definition":"fluent" },
      { "word":"waffle","definition":"talk vaguely and without much result" },
      { "word":"waft","definition":"scent waving movement carry lightly through" },
      { "word":"wag","definition":"merry person" },
      { "word":"warmonger","definition":"person who stirs up war" },
      { "word":"warrant","definition":"authority written order guarantee" },
      { "word":"wean","definition":"to turn away (from a habit)" },
      { "word":"weigh","definition":"measure hoe heavy smth is" },
      { "word":"welter","definition":"turmoil a bewildering jumble" },
      { "word":"wend","definition":"to go proceed" },
      { "word":"whimsical","definition":"full of odd and fanciful ideas" },
      { "word":"wince","definition":"show bodily or mental pain" },
      { "word":"woo","definition":"try to win" },
      { "word":"writ","definition":"written order" },
      { "word":"yarn","definition":"tale story fibers for knitting" }
    ]

class RandomWord(object):
	"""
	{'word': str, 'definition': str}
	"""

	def __init__(self):
		self.data = data

	def __str__(self):
		w = self.__get_word()
		return "# %s : %s" % (w['word'], w['definition'])

	def __get_word(self):
		return self.data[randint(0, len(self.data) - 1)]

	def get(self):
		return self.__get_word()
